@@ -2,11 +2,11 @@ package Aspect::Library::Breakpoint;
 
 use strict;
 use warnings;
-use Aspect::Library        ();
+use Aspect::Modular        ();
 use Aspect::Advice::Before ();
 
-our $VERSION = '0.97_06';
-our @ISA     = 'Aspect::Library';
+our $VERSION = '0.38';
+our @ISA     = 'Aspect::Modular';
 
 sub get_advice {
 	my $self = shift;
@@ -14,7 +14,6 @@ sub get_advice {
 		lexical  => $self->lexical,
 		pointcut => $_[0],
 		code     => sub {
-			no warnings;
 			$DB::single = 1;
 		},
 	);
@@ -33,20 +32,30 @@ Aspect::Library::Breakpoint - A breakpoint aspect
 =head1 SYNOPSIS
 
   use Aspect;
-  
+
   aspect Breakpoint => call qr/^Foo::refresh/;
-  
+
   my $f1 = Foo->refresh_foo;
   my $f2 = Foo->refresh_bar;
-  
+
   # The debugger will go into single statement mode for both methods
 
+=head1 SUPER
+
+L<Aspect::Modular>
+
 =head1 DESCRIPTION
 
+B<THIS MODULE IS EXPERIMENTAL AND SUBJECT TO CHANGE WITHOUT NOTICE>
+
 C<Aspect::Library::Breakpoint> is a reusable aspect for implementing
 breakpoints in the debugger in patterns that are more complex than
 the native debugger supports.
 
+=head1 SEE ALSO
+
+See the L<Aspect> pods for a guide to the Aspect module.
+
 =head1 AUTHORS
 
 Adam Kennedy E<lt>adamk@cpan.orgE<gt>
