@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Aspect::Pointcut ();
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 our @ISA     = 'Aspect::Pointcut';
 
 
@@ -18,6 +18,13 @@ sub match_define {
 	return ! shift->[0]->match_define(@_);
 }
 
+sub match_contains {
+	my $self = shift;
+	return 1 if $self->isa($_[0]);
+	return 1 if $self->[0]->match_contains($_[0]);
+	return '';
+}
+
 # Logical not inherits it's curryability from the element contained
 # within it. We continue to be needed if and only if something below us
 # continues to be needed as well.
